@@ -7,12 +7,18 @@ Desc: 命令行运行主文件
 import os
 import sys
 from argparse import ArgumentParser
+from subprocess import run
 
 import aktools
 
 
 def get_parser():
-    parser = ArgumentParser(description="AKShare's HTTP Server")
+    """
+    增加 解析属性
+    :return:
+    :rtype:
+    """
+    parser = ArgumentParser(description="AKShare's HTTP API Server")
     parser.add_argument(
         "-V",
         "--version",
@@ -53,7 +59,12 @@ def get_parser():
     return parser
 
 
-def main():
+def main() -> None:
+    """
+    主程序
+    :return:
+    :rtype:
+    """
     args = sys.argv[1:]
     parser = get_parser()
     options = parser.parse_args(args)
@@ -63,8 +74,6 @@ def main():
     )
     print(file_address)
     order_str = f"uvicorn api:app --host {options.host} --port {options.port} --app-dir {file_address}"
-    # os.system(order_str)
-    from subprocess import run
     run(order_str, shell=True)
 
 
